@@ -3,7 +3,7 @@ package Web::Microformats2;
 use Web::Microformats2::Parser;
 use Web::Microformats2::Document;
 
-our $VERSION = '0.5';
+our $VERSION = '0.401';
 
 1;
 
@@ -45,7 +45,7 @@ it as a queryable in-memory object. They can also serialize this object
 as JSON (using the Microformats2 rules for this), or read an already
 JSON-serialized Microformats2 structure for further analysis.
 
-See L<"ABOUT MICROFORMATS2">, below, for arguments about why this might
+See L<"ABOUT MICROFORMATS">, below, for arguments about why this might
 be interesting to you.
 
 =head1 CLASSES
@@ -75,15 +75,16 @@ of properties, and possibly a parent item and a list of child items.
 
 =head1 STATUS
 
-These modules provide a I<reasonably complete> implementation of L<the
-Microformats2 Living
-Specification|http://microformats.org/wiki/microformats2-parsing>. They
-pass all of L<the official MF2 baseline test
-cases|https://github.com/microformats/tests>, a copy of which is
-included with these modules' own test suite.
+These modules are B<alpha>. Their developer is still figuring out how
+they want to be used, and their interface may change dramatically. This
+software is currently being "dogfooded" on an experimental branch of the
+author's own essay blog.
 
-The author considers this software B<beta>. Its public interface may
-still change, but not without some effort at supporting its current API.
+Further, the parser implementation is incomplete. The HTML and JSON
+documents found in t/microformats-v2 are based on the full Microformats2
+parser test suite found at L<https://github.com/microformats/tests>, as
+of mid-2018, and this library currently passes around 80 percent of
+them.
 
 =head1 ABOUT MICROFORMATS2
 
