@@ -8,7 +8,6 @@ use v5.10;
 use Scalar::Util;
 use JSON;
 use DateTime::Format::ISO8601;
-use Carp;
 
 use Web::Microformats2::Item;
 use Web::Microformats2::Document;
@@ -57,15 +56,12 @@ sub parse {
 
 # analyze_element: Recursive method that scans an element for new microformat
 # definitions (h-*) or properties (u|dt|e|p-*) and then does the right thing.
-# It also builds up the MF2 document's rels and rel-urls as it goes.
 sub analyze_element {
     my $self = shift;
     my ( $document, $element, $current_item ) = @_;
 
     return unless blessed( $element) && $element->isa( 'HTML::Element' );
 
-    $self->_add_element_rels_to_mf2_document( $element, $document );
-
     my $mf2_attrs = $self->_tease_out_mf2_attrs( $element );
 
     my $h_attrs = delete $mf2_attrs->{h};
@@ -93,12 +89,19 @@ sub analyze_element {
             # this property name.)
             unless ( $new_item ) {
                 for my $property ( @$properties_ref ) {
-                    my $value = $self->_parse_property_value( $element );
-                    if ( defined $value ) {
+                    my $vcp_fragments_ref =
+                        $self->_seek_value_class_pattern( $element );
+                    if ( @$vcp_fragments_ref ) {
                         $current_item->add_property(
                             "p-$property",
-                            $value,
-                        );
+                            join q{}, @$vcp_fragments_ref,
+                        )
+                    }
+                    elsif ( my $alt = $element->findvalue( './@title|@value|@alt' ) ) {
+                        $current_item->add_property( "p-$property", $alt );
+                    }
+                    elsif ( my $text = _trim( decode_entities($element->as_text) ) ) {
+                        $current_item->add_property( "p-$property", $text );
                     }
                 }
             }
@@ -184,7 +187,7 @@ sub analyze_element {
                 my $vcp_fragments_ref =
                     $self->_seek_value_class_pattern( $element );
                 if ( @$vcp_fragments_ref ) {
-                    $dt_string = $self->_format_datetime(join (q{T}, @$vcp_fragments_ref), $current_item);
+                    $dt_string = $self->_format_datetime(join q{T}, @$vcp_fragments_ref);
                 }
                 elsif ( my $alt = $element->findvalue( './@datetime|@title|@value' ) ) {
                     $dt_string = $alt;
@@ -219,21 +222,13 @@ sub analyze_element {
 
         # Now add a "value" attribute to this new item, if appropriate,
         # according to the MF2 spec.
-        my $value_attribute;
         if ( $mf2_attrs->{p}->[0] ) {
-            if ( my $name = $new_item->get_properties('name')->[0] ) {
-                $value_attribute = $name;
-            }
-            else {
-                $value_attribute = $self->_parse_property_value( $element );
-            }
+            $new_item->value( $new_item->get_properties('name')->[0] );
         }
         elsif ( $mf2_attrs->{u}->[0] ) {
-            $value_attribute = $new_item->get_properties('url')->[0];
+            $new_item->value( $new_item->get_properties('url')->[0] );
         }
 
-        $new_item->value( $value_attribute ) if defined ($value_attribute);
-
         # Put this onto the parent item's property-list, or its children-list,
         # depending on context.
         my $item_property;
@@ -338,7 +333,7 @@ sub _set_implied_name {
 
     my $types = $item->types;
 
-    return if $item->has_properties || $item->has_children;
+    return if $item->has_p_properties || $item->has_e_properties;
 
     my $xpath;
     my $name;
@@ -552,7 +547,7 @@ sub _trim {
 }
 
 sub _format_datetime {
-    my ($self, $dt_string, $current_item) = @_;
+    my ($self, $dt_string) = @_;
 
     my $dt;
 
@@ -561,7 +556,7 @@ sub _format_datetime {
 
     $dt_string =~ s/t/T/;
 
-    # Note presence of AM/PM, but toss it out of the string.
+    # XXX Will have to come back to this...
     $dt_string =~ s/((?:a|p)\.?m\.?)//i;
     my $am_or_pm = $1 || '';
 
@@ -590,21 +585,6 @@ sub _format_datetime {
     # Treat a space separator between date & time as a 'T'.
     $dt_string =~ s/ /T/;
 
-    # If this is a time with no date, try to apply a previously-seen
-    # date to it.
-    my $date_is_defined = 1;
-    if ( $dt_string =~ /^\d\d:/ ) {
-        if ( my $previous_dt = $current_item->last_seen_date ) {
-            $dt_string = $previous_dt->ymd . "T$dt_string";
-        }
-        else {
-            $date_is_defined = 0;
-            carp "Encountered a value-class datetime with only a time, "
-                 . "no date, and no date defined earlier. Results may "
-                 . "not be what you expect. (Data: $dt_string)";
-        }
-    }
-
     eval {
     $dt = DateTime::Format::ISO8601->new
               ->parse_datetime( $dt_string );
@@ -612,10 +592,6 @@ sub _format_datetime {
 
     return if $@;
 
-    if ($date_is_defined) {
-        $current_item->last_seen_date( $dt );
-    }
-
     if ($am_or_pm =~ /^[pP]/) {
         # There was a 'pm' specified, so add 12 hours.
         $dt->add( hours => 12 );
@@ -643,61 +619,6 @@ sub _format_datetime {
     return $dt->strftime( $format );
 }
 
-sub _parse_property_value {
-    my ( $self, $element ) = @_;
-
-    my $value;
-
-    my $vcp_fragments_ref =
-        $self->_seek_value_class_pattern( $element );
-    if ( @$vcp_fragments_ref ) {
-        $value = join q{}, @$vcp_fragments_ref;
-    }
-    elsif ( my $alt = $element->findvalue( './@title|@value|@alt' ) ) {
-        $value = $alt;
-    }
-    elsif ( my $text = _trim( decode_entities($element->as_text) ) ) {
-        $value = $text;
-    }
-
-    return $value;
-}
-
-sub _add_element_rels_to_mf2_document {
-    my ( $self, $element, $document ) = @_;
-
-    return unless $element->tag =~ /^(a|link)$/;
-
-    my $rel = $element->attr( 'rel' );
-    return unless defined $rel;
-
-    my $href = $element->attr( 'href' );
-    my $url = URI->new_abs( $href, $self->url_context)->as_string;
-
-    my @rels = split /\s+/, $rel;
-    for my $rel ( @rels ) {
-        $document->add_rel( $rel, $url );
-    }
-
-    my $rel_url_value = {};
-    foreach (qw( hreflang media title type ) ) {
-        next if defined $rel_url_value->{ $_ };
-        my $value = $element->attr( $_ );
-        if ( defined $value ) {
-            $rel_url_value->{ $_ } = $value;
-        }
-    }
-    my $text = ($element->as_text);
-    if ( defined $text ) {
-        $rel_url_value->{ text } = $text;
-    }
-
-    $rel_url_value->{ rels } = \@rels;
-
-    $document->add_rel_url( $url, $rel_url_value );
-
-}
-
 1;
 
 =pod
